@@ -1,5 +1,7 @@
-from typing import Any, Dict, List, Literal
+from typing import Any, Dict, List
+from typing_extensions import Literal
 
+import json
 import pendulum
 from pendulum.datetime import DateTime
 from swimlane import Swimlane
@@ -9,8 +11,11 @@ _LEVELS = ["debug", "info", "warning", "error", "critical"]
 
 
 class UseCaseOutcome:
-    def __init__(self, sl: Swimlane) -> None:
+    def __init__(self, sl: Swimlane, app_name: str, integration_name: str, **default_fields) -> None:
         self.sl = sl
+        self.app_name = app_name
+        self.integration_name = integration_name
+        self.default_fields = default_fields
         self.logs: List[Dict[str, str]] = []
         self.metrics: List[Dict[str, str]] = []
         self.fields_changed: List[Dict[str, str]] = []
@@ -40,12 +45,12 @@ class UseCaseOutcome:
         # we need to change the fields_changed datetimes to the current date/time as it is only saved now.
         p_load: Dict[str, Any] = {
             "status": status,
-            "application_name": "test_application",
-            "integration_name": "test_integration",
+            "application_name": self.app_name,
+            "integration_name": self.integration_name,
             **self.arbitrary_record_fields,
-            "raw_metrics": self.metrics,
-            "raw_logs": self.logs,
-            "raw_fields_changed": self.fields_changed,
+            "raw_metrics": json.dumps(self.metrics),
+            "raw_logs": json.dumps(self.logs),
+            "raw_fields_changed": json.dumps([field_changed for field_changed in self.fields_changed if "timestamp" in field_changed]),
             "auto_close": "YES" if auto_closed else "NO",
             "start_time": self.use_case_started.to_iso8601_string().replace(":", "-"),
             "end_time": et.to_iso8601_string().replace(":", "-"),
@@ -70,7 +75,7 @@ class UseCaseOutcome:
                 f"level must be one of the following : {','.join(_LEVELS)}"
             )
 
-        self.logs.append({**kwargs, "level": level})
+        self.logs.append({**kwargs, "level": level, **self.default_fields, "timestamp": pendulum.now().to_iso8601_string()})
 
     def metric(self, metric_name: str, metric_value: Any):
         self.metrics.append({"metric_name": metric_name, "metric_value": metric_value})
